<?php
class WC_Settings_Tab_Sendlane {
    /**
     * Bootstraps the class and hooks required actions & filters.
     *
     */
    public static function init() {
        add_filter( 'woocommerce_settings_tabs_array', __CLASS__ . '::add_settings_tab', 50 );
        add_action( 'woocommerce_settings_tabs_sfw-settings_sendlane', __CLASS__ . '::settings_tab' );
        add_action( 'woocommerce_update_options_sfw-settings_sendlane', __CLASS__ . '::update_settings' );
    }
    
    
    /**
     * Add a new settings tab to the WooCommerce settings tabs array.
     *
     * @param array $settings_tabs Array of WooCommerce setting tabs & their labels, excluding the Subscription tab.
     * @return array $settings_tabs Array of WooCommerce setting tabs & their labels, including the Subscription tab.
     */
    public static function add_settings_tab( $settings_tabs ) {
        $settings_tabs['sfw-settings_sendlane'] = __( 'Sendlane', 'sendlaneforwoocommerce' );
        return $settings_tabs;
    }
    /**
     * Uses the WooCommerce admin fields API to output settings via the @see woocommerce_admin_fields() function.
     *
     * @uses woocommerce_admin_fields()
     * @uses self::get_settings()
     */
    public static function settings_tab() {
        woocommerce_admin_fields( self::get_settings() );
    }
    /**
     * Uses the WooCommerce options API to save settings via the @see woocommerce_update_options() function.
     *
     * @uses woocommerce_update_options()
     * @uses self::get_settings()
     */
    public static function update_settings() {
        woocommerce_update_options( self::get_settings() );
    }
	
	public static function get_autoresponder_settting(){
		$results = get_option('sfw_subscriber_settings');
		return $results;
	}
	
	public static function get_autoresponder_lists(){
		//$autoresponder = get_option('sfw_autoresponder_email');
		$autoresponder = 'Sendlane';
		
		if(empty($autoresponder)) return array();
		
		$data = WC_Settings_Tab_Sendlane::get_autoresponder_settting();		
		$apikey = $data[$autoresponder];
		
		$objlist = new sfw_subscriber();
		$list = $objlist->switch_responder($apikey, 'getList', $autoresponder);
		
		return $list['list'];
	}
    /**
     * Get all the settings for this plugin for @see woocommerce_admin_fields() function.
     *
     * @return array Array of settings for @see woocommerce_admin_fields() function.
     */
    public static function get_settings() {
		
		$data = WC_Settings_Tab_Sendlane::get_autoresponder_settting();
		
		$emaillists = array('select');
		
		if(is_array($data)){
			foreach($data as $k=>$v){
				$emaillists[$k] = $k;	
			}
		}
		
		$list = WC_Settings_Tab_Sendlane::get_autoresponder_lists();
		
        $settings = array(
            'section_title' => array(
                'name'     => __( 'Sendlane', 'sendlaneforwoocommerce' ),
                'type'     => 'title',
                'desc'     => '',
                'id'       => 'sfw_autoresponder_section_title'
            ),
            /*'responder' => array(
                'name' 		  => __( 'Select Email Service Provider', 'sendlaneforwoocommerce' ),
                'type' 		  => 'select',
                'default'     => 'Mailchimp',
				'options'     => $emaillists,
				'class'       => 'sfw-autoresponder-select wc-enhanced-select',
				'css'         => 'min-width: 350px;',
				//'desc_tip'    =>  true,
				'id'  		  => 'sfw_autoresponder_email'
            ),*/
			'listId' => array(
                'name' 		  => __( 'Select List', 'sendlaneforwoocommerce' ),
                'type' 		  => 'select',
                'default'     => '',
				'options'     => $list,
				'class'       => 'sfw-autoresponder-list-select wc-enhanced-select',
				'css'         => 'min-width: 350px;',
				//'desc_tip'    =>  true,
				'id'  		  => 'sfw_autoresponder_listId',
				'desc'     => __( '<p><a href="'.admin_url('options-general.php?page=sfw-main-page').'">Get List</a></p>', 'sendlaneforwoocommerce' ),
            )
        );

		$settings[] = array(
			'id'       => 'sfw_autoresponder_display_opt_in',
			'title'    => __( 'Subscribe Customers', 'sendlaneforwoocommerce' ),
			'desc'     => __( '<p>Choose <strong>Ask for permission</strong> to show an "Opt-in" checkbox during checkout. Customers will only be subscribed to the list above if they opt-in. <p>Choose <strong>Automatically</strong> to subscribe customers silently upon checkout. Caution, this is without the customer\'s consent.</p>', 'sendlaneforwoocommerce' ),
			'type'     => 'select',
			'css'      => 'min-width:350px;',
			'class'    => 'wc-enhanced-select',
			'desc_tip' => true,
			'default'  => 'yes',
			'options'  => array(
				'yes' => __( 'Ask for permission', 'sendlaneforwoocommerce' ),
				'no' => __( 'Automatically', 'sendlaneforwoocommerce' ),
			)
		);

		$settings[] = array(
			'id'          => 'sfw_autoresponder_opt_in_label',
			'title'       => __( 'Opt-In Field Label', 'sendlaneforwoocommerce' ),
			'type'        => 'text',
			'desc'        => __( 'Optional: customize the label displayed next to the opt-in checkbox.', 'sendlaneforwoocommerce' ),
			'default'     => __( 'Subscribe to our newsletter', 'sendlaneforwoocommerce' ),
			'css'         => 'min-width:350px;',
			'desc_tip'    =>  true,
		);

		$settings[] = array(
			'id'          => 'sfw_autoresponder_opt_in_checkbox_default_status',
			'title'       => __( 'Opt-In Checkbox Default', 'sendlaneforwoocommerce' ),
			'type'        => 'select',
			'desc'        => __( 'The default state of the opt-in checkbox.', 'sendlaneforwoocommerce' ),
			'css'         => 'min-width: 350px;',
			'class'       => 'wc-enhanced-select',
			'default'     => 'checked',
			'options'     => array(
				'checked'   => __( 'Checked', 'sendlaneforwoocommerce' ),
				'unchecked' => __( 'Unchecked', 'sendlaneforwoocommerce' )
			),
			'desc_tip'    =>  true,
		);

		$settings[] = array(
			'id'          => 'sfw_autoresponder_opt_in_checkbox_display_location',
			'title'       => __( 'Opt-In Checkbox Location', 'sendlaneforwoocommerce' ),
			'type'        => 'select',
			'desc'        => __( 'Where to display the opt-in checkbox on the checkout page.', 'sendlaneforwoocommerce' ),
			'class'       => 'wc-enhanced-select',
			'css'         => 'min-width: 350px;',
			'default'     => 'woocommerce_review_order_before_submit',
			'options'     => array(
				'woocommerce_checkout_before_customer_details' => __( 'Above customer details', 'sendlaneforwoocommerce' ),
				'woocommerce_checkout_after_customer_details' => __( 'Below customer details', 'sendlaneforwoocommerce' ),
				'woocommerce_review_order_before_submit' => __( 'Order review above submit', 'sendlaneforwoocommerce' ),
				'woocommerce_review_order_after_submit' => __( 'Order review below submit', 'sendlaneforwoocommerce' ),
				'woocommerce_review_order_before_order_total' => __( 'Order review above total', 'sendlaneforwoocommerce' ),
				'woocommerce_checkout_billing' => __( 'Above billing details', 'sendlaneforwoocommerce' ),
				'woocommerce_checkout_shipping' => __( 'Above shipping details', 'sendlaneforwoocommerce' ),
				'woocommerce_after_checkout_billing_form' => __( 'Below Checkout billing form', 'sendlaneforwoocommerce' ),
			),
			'desc_tip'    =>  true,
		);
		
		$settings[] = array( 'type' => 'sectionend', 'id' => 'wc_settings_tab_demo_section_end' );
		
		
        return apply_filters( 'wc_settings_tab_demo_settings', $settings );
    }
}
WC_Settings_Tab_Sendlane::init();