<?php
/*
 * Plugin Name: Sendlane for WooCommerce
 * Plugin URI: 
 * Description: Allowing you to capture your buyers for WooCommerce into your Sendlane account.
 * Version: 1.0.0
 * Author: Sendlane
 * Author URI: https://sendlane.com/
 */
 
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * The code that runs during plugin activation.
 */
function sfw_activate() {
	// do stuff
}

/**
 * The code that runs during plugin deactivation.
 */
function sfw_deactivate() {
	// do stuff
}

register_activation_hook( __FILE__, 'sfw_activate' );
register_deactivation_hook( __FILE__, 'sfw_deactivate' );

define( 'SFW_PATH', plugin_dir_path( __FILE__) );
define('SFW_URL', plugins_url('', __FILE__));

add_action( 'plugins_loaded', 'sfw_load_plugin_textdomain' );
/**
 * Load the plugin text domain for translation.
 *
 * @since    1.0.0
 */
function sfw_load_plugin_textdomain() {
	
	load_plugin_textdomain(
		'sendlaneforwoocommerce',
		false,
		dirname( dirname( plugin_basename( __FILE__ ) ) ) . '/languages/'
	);

}

add_action('admin_menu', 'sfw_settings_menu');
function sfw_settings_menu(){
	add_submenu_page(
		'options-general.php',
		esc_html__('Sendlane WooCommerce', 'sendlaneforwoocommerce'),
		esc_html__('Sendlane WooCommerce', 'sendlaneforwoocommerce'),
		 'manage_options',
		'sfw-main-page',
		'sfw_main_page'
	);
}

function sfw_main_page(){
	wp_enqueue_style('sfw_admin_css',  SFW_URL . '/assets/css/admin.css');
	wp_enqueue_script('sfw_admin_js', SFW_URL . '/assets/js/admin.js', array('jquery'), '1.0.0',true);
	wp_localize_script( 'sfw_admin_js', 'sfw_ajaxurl', array( 'url' => admin_url('admin-ajax.php') ) );
	require SFW_PATH . 'includes/sfw-settings.php';
}

add_action( 'admin_enqueue_scripts', 'sfw_woocommerce_enqueue_scripts' );
function sfw_woocommerce_enqueue_scripts(){
	wp_enqueue_script('sfw_woo_admin_js', SFW_URL . '/assets/js/woocommerce-admin.js', array('jquery'), '1.0.0',true);
	wp_localize_script( 'sfw_woo_admin_js', 'sfw_ajaxurl', array( 'url' => admin_url('admin-ajax.php') ) );
}

require SFW_PATH . 'includes/sfw-subscriber.php';
require SFW_PATH . 'includes/sfw-woocommerce-setting.php';
require SFW_PATH . 'includes/sfw-wp-ajax.php';

if(!class_exists('sfw_autoresponder_handler')){
	class sfw_autoresponder_handler{
		function __construct(){
			$this->register_hook();
		}
		
		public function register_hook(){
			$location = get_option( 'sfw_autoresponder_opt_in_checkbox_display_location' );
			$location = !empty( $location ) ? $location : 'woocommerce_review_order_before_submit';
			add_action( $location, array( $this, 'add_checkout_fields' ) );
			
			// hook into woocommerce order status changed hook to handle the desired subscription event trigger
			add_action( 'woocommerce_order_status_changed', array( $this, 'order_status_changed' ), 10, 3 );
		}
		
		private function wc_get_order( $order_id ) {
			if ( function_exists( 'wc_get_order' ) ) {
				return wc_get_order( $order_id );
			} else {
				return new WC_Order( $order_id );
			}
		}
		
		public function save_checkout_fields( $order_id ) {
			$display_opt_in = get_option( 'sfw_autoresponder_display_opt_in' );
			if ( $display_opt_in == 'yes' ) {
				return isset( $_POST[ 'sfw_autoresponder_mailchimp_opt_in' ] ) ? 'yes' : 'no';
			}else{
				return 'yes';
			}
		}
		
		public function order_status_changed( $id, $status = 'new', $new_status = 'pending' ) {
			
			// Get WC order
			$order = $this->wc_get_order( $id );

			$subscribe_customer = $this->save_checkout_fields($id);
			if ( ! $subscribe_customer || empty( $subscribe_customer ) || 'yes' === $subscribe_customer ) {
				/*$autoresponder = get_option('sfw_autoresponder_email');*/		
				$autoresponder = 'Sendlane';
				if(empty($autoresponder)) return false;					
				$data = WC_Settings_Tab_Sendlane::get_autoresponder_settting();
				$apikey = $data[$autoresponder];
				$apikey['listid'] = get_option( 'sfw_autoresponder_listId' );
				$apikey['email'] = $order->billing_email;
				$apikey['name'] = $order->billing_first_name . ' ' . $order->billing_last_name;
				$objlist = new sfw_subscriber();
				$result = $objlist->switch_responder($apikey, 'subsCribe', $autoresponder);
				
				if(isset($result['success'])){
					update_post_meta($id, 'sfw_autoresponder_mail_status', 'success');
				}elseif(isset($result['error'])){
					update_post_meta($id, 'sfw_autoresponder_mail_status', 'fail');
				}else{
					update_post_meta($id, 'sfw_autoresponder_mail_status', $apikey);
				}
			}
			
		}
		
		public function add_checkout_fields(){
			$display_opt_in = get_option( 'sfw_autoresponder_display_opt_in' );
			$default_status = get_option( 'sfw_autoresponder_opt_in_checkbox_default_status' );
			$label = get_option( 'sfw_autoresponder_opt_in_label' );
			if ( $display_opt_in == 'yes' ) {
				do_action( 'sfw_autoresponder_before_opt_in_checkbox' );
				echo apply_filters( 'sfw_autoresponder_opt_in_checkbox' , '<p class="form-row woocommerce-mailchimp-opt-in"><label for="sfw_autoresponder_mailchimp_opt_in"><input type="checkbox" name="sfw_autoresponder_mailchimp_opt_in" id="sfw_autoresponder_mailchimp_opt_in" value="yes"' . ($default_status == 'checked' ? ' checked="checked"' : '') . '/> ' . esc_html( $label ) . '</label></p>' . "\n", $default_status, $label );
				do_action( 'sfw_autoresponder_after_opt_in_checkbox' );
			}
		}
	}
	new sfw_autoresponder_handler();
}